@@ -11,6 +11,7 @@ import unittest
 import doctest
 
 from webget import WebgetTool
+from xnet.net.ipv4 import IPRangeIterator
 
 
 class IISShortnameTool(WebgetTool):
@@ -31,6 +32,18 @@ class IISShortnameTool(WebgetTool):
             dict(dest='code', action='store_true')),
     ]
 
+    @classmethod
+    def __massage__(self, iterator):
+        for item in iterator:
+            item = item.strip()
+            try:
+                iprangeiter = IPRangeIterator(item)
+            except ValueError:
+                yield item
+            else:
+                for ip in iprangeiter:
+                    yield str(ip)
+
     def __parse__(self, line, iterator):
         result = super(IISShortnameTool, self).__parse__(line, iterator)
         url = result['url']
